@@ -1777,10 +1777,3 @@ def betweenness_centrality(edge_list, delta_t, alpha, epsilon):
                             betweenness = betweenness + temp_betweenness
     betweenness = dict(zip(nodes, betweenness))
     return betweenness
-
-
-G = nx.DiGraph()
-G.add_edge(1,3)
-G.add_edge('u', 2)
-x, y = node_directed_subgraph_centrality(G, 'u', t=4)
-print(x, y)
